@@ -31,8 +31,8 @@ setup::debian::install() {
 }
 
 setup::rh::yuminst() {
-    # yum has no update-only verb
-    yum -y --nogpgcheck install $@
+    # yum has no update-only verb.  Also: modularity just makes this slower.
+    yum -y --nogpgcheck --disablerepo=\*modul\* install $@
 }
 
 setup::centos::install() {
@@ -67,7 +67,8 @@ setup::rh::install() {
 }
 
 setup::macos::install() {
-    # install Python from pyenv so we know what version is being used
+    # Install Python from pyenv so we know what version is being used.  This
+    # doesn't work for newer macos.
     pyenv install $PYENV
     pyenv global $PYENV
     virtualenv -p $(pyenv which python) .venv
@@ -83,13 +84,6 @@ setup::windows::install() {
     # Update path to include them
     export PATH="$PYPATH:$PYPATH/Scripts:/c/Program Files/MIT/Kerberos/bin:$PATH"
 
-    if [ "${PYENV:0:1}" == "2" ]; then
-        choco install vcredist2008
-        # Skip dotnet dependency:
-        # https://github.com/fredrikaverpil/vcpython27/pull/3
-        choco install --ignore-dependencies vcpython27
-    fi
-
     python -m pip install --upgrade pip
 }
 
